"use server";

import { requestGetFetch, requestPostFetch } from "@/utils/fetch";
import { getServerSession, Session } from "next-auth";
import { nextauthOptions } from "../nextauth-options";
import { SearchParams } from "@/types/searchParams";


export async function attendanceRequestList(searchParams?: SearchParams) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const paramsArray = searchParams && Object.entries(searchParams);

    const queryString = paramsArray && paramsArray.map(([key, value]) => `${key}=${value}`).join('&');

    const path = 'v1/attendances' + (queryString ? `?${queryString}` : '');

    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}

export async function getAttendanceById(id: number) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;
    const path = `v1/attendances/${id}`;
    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });
    return response.data || null;
  } catch (error) {
    throw error;
  }
}

export async function getAttendanceByDate(date: Date | string) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;
    const path = `v1/attendances/get-by-date?date=${date ? date : ''}`;
    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });
    return response.data || null;
  } catch (error) {
    throw error;
  }
}


export async function editAttendanceRequest(payload: { userId: string; data: any }) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;
    const path = "v1/attendances/" + payload?.userId;
    const response = await requestGetFetch({
      path,
      options: {
        method: "PUT",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        body: JSON.stringify(payload?.data),
        cache: 'no-store',
      },
    });
    return response;
  } catch (error: any) {
    throw new Error(error.message);
  }
}


export async function createAttendanceRequest(payload: any) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const path = "v1/attendances";

    const response = await requestPostFetch({
      path,
      data: { ...payload },
      token: token,
    });

    return response
  } catch (error: any) {
    throw new Error(error.message);
  }
}


export async function deleteAttendance(id: number | string) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;
    const path = "v1/attendances/" + id;
    const response = await requestGetFetch({
      path,
      options: {
        method: "Delete",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}



export async function createLocationRequest(payload: any) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const path = "v1/locations";

    const response = await requestPostFetch({
      path,
      data: { ...payload },
      token: token,
    });

    return response
  } catch (error: any) {
    throw new Error(error.message);
  }
}